==> huaweicloudsdkcodehub-3.1.86-py2.py3-none-any.whl: huaweicloudsdkcodehub/v3/model/add_protect_request.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class AddProtectRequest:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'access_level': 'AddProtectAccessLevel'
    }

    attribute_map = {
        'access_level': 'access_level'
    }

    def __init__(self, access_level=None):
        """AddProtectRequest

        The model defined in huaweicloud sdk

        :param access_level: 
        :type access_level: :class:`huaweicloudsdkcodehub.v3.AddProtectAccessLevel`
        """
        
        

        self._access_level = None
        self.discriminator = None

        self.access_level = access_level

    @property
    def access_level(self):
        """Gets the access_level of this AddProtectRequest.

        :return: The access_level of this AddProtectRequest.
        :rtype: :class:`huaweicloudsdkcodehub.v3.AddProtectAccessLevel`
        """
        return self._access_level

    @access_level.setter
    def access_level(self, access_level):
        """Sets the access_level of this AddProtectRequest.

        :param access_level: The access_level of this AddProtectRequest.
        :type access_level: :class:`huaweicloudsdkcodehub.v3.AddProtectAccessLevel`
        """
        self._access_level = access_level

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, AddProtectRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkcodehub-3.1.152-py2.py3-none-any.whl: huaweicloudsdkcodehub/v3/model/add_protect_request.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class AddProtectRequest:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'access_level': 'AddProtectAccessLevel'
    }

    attribute_map = {
        'access_level': 'access_level'
    }

    def __init__(self, access_level=None):
        r"""AddProtectRequest

        The model defined in huaweicloud sdk

        :param access_level: 
        :type access_level: :class:`huaweicloudsdkcodehub.v3.AddProtectAccessLevel`
        """
        
        

        self._access_level = None
        self.discriminator = None

        self.access_level = access_level

    @property
    def access_level(self):
        r"""Gets the access_level of this AddProtectRequest.

        :return: The access_level of this AddProtectRequest.
        :rtype: :class:`huaweicloudsdkcodehub.v3.AddProtectAccessLevel`
        """
        return self._access_level

    @access_level.setter
    def access_level(self, access_level):
        r"""Sets the access_level of this AddProtectRequest.

        :param access_level: The access_level of this AddProtectRequest.
        :type access_level: :class:`huaweicloudsdkcodehub.v3.AddProtectAccessLevel`
        """
        self._access_level = access_level

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, AddProtectRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
